@@ -1,36 +1,22 @@
-/***************************************************************************
-                              ExerciseFactorize.cpp
-                             -------------------
-    begin                : 2004/06/04
-    copyright            : (C) 2004 by Sebastian Stein
-    email                : seb.kde@hpfsc.de
+/*
+    SPDX-FileCopyrightText: 2004 Sebastian Stein <seb.kde@hpfsc.de>
+    SPDX-FileCopyrightText: 2008 Tadeu Araujo <tadeu.araujo@ltia.fc.unesp.br>
+    SPDX-FileCopyrightText: 2008 Danilo Balzaque <danilo.balzaque@ltia.fc.unesp.br>
 
-    copyright            : (C) 2008 by Tadeu Araujo, tadeu.araujo@ltia.fc.unesp.br
-    copyright            : (C) 2008 by Danilo Balzaque, danilo.balzaque@ltia.fc.unesp.br
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "ExerciseFactorize.h"
 
 /* these includes are needed for KDE support */
 #include <KLocalizedString>
-#include <KMessageBox>
 
 /* these includes are needed for Qt support */
 #include <QApplication>
 #include <QGridLayout>
 #include <QLabel>
-#include <QLayout>
 #include <QPushButton>
-#include <QPainter>
+#include <QRandomGenerator>
 
 #ifdef DEBUG
 #include <QDebug>
@@ -332,7 +318,7 @@ void ExerciseFactorize::createTask()
     PrimeNumber tmp_primenumber;
 
     // just pick one number out of the possible numbers to factorize
-    m_taskNumber = possibleTasks[uint((double(qrand()) / RAND_MAX) * numberPossibleTasks)];
+    m_taskNumber = possibleTasks[QRandomGenerator::global()->bounded(numberPossibleTasks)];
 
     // now get the primefactors of the taskNumber
     m_factorsResult.clear();
